@@ -17,7 +17,7 @@
 
 
 SUPERMATRIX <- function(x,keep_names=FALSE) {
-  x <- .Call(`_mrgsolve_SUPERMATRIX`,x,keep_names)
+  x <- .Call(`_mrgsolve_SUPERMATRIX`,x,keep_names,PACKAGE="mrgsolve")
   if(nrow(x) > 0 & !keep_names) {
     dimnames(x) <- list(paste0(seq_len(nrow(x)), ": "), NULL)
   }
